@@ -5,6 +5,7 @@ import torch.nn as nn
 from IPython import get_ipython
 from torch import optim
 from torchvision import models
+from tqdm import tqdm
 
 from diamond.user_classes import ImagesData, ImageModel
 
@@ -85,10 +86,32 @@ class ImageModelTraining:
         train_loss, evaluate_accuracy = 0, 0
         for epoch in range(self.num_epochs):
             print(f"Epoch {epoch + 1}/{self.num_epochs}")
-            train_loss = self.train_model_epoch(model, self.train_loader, criterion, optimizer)
+            running_loss = 0.0
+            with tqdm(total=len(self.train_loader)) as progress_bar:
+                for i, (inputs, labels) in enumerate(self.train_loader, 0):
+                    optimizer.zero_grad()
+
+                    inputs, labels = inputs.to(self.device), labels.to(self.device)
+
+                    try:
+                        outputs = model(inputs.float())
+                    except Exception as e:
+                        print(f"Error while running model: {e}")
+                        print("Input size:", inputs.size())
+
+                    loss = criterion(outputs, labels)
+                    loss.backward()
+
+                    optimizer.step()
+
+                    running_loss += loss.item()
+                    progress_bar.update(1)
+                    progress_bar.set_description(f"Training loss: {running_loss / (i + 1):.4f}")
+
             evaluate_accuracy = self.evaluate_model(model=model, data_loader=self.val_loader, device=self.device)
-            print(f"Train Loss: {train_loss:.4f} - Evaluate Accuracy: {evaluate_accuracy:.4f}")
-        return train_loss, evaluate_accuracy
+            print(
+                f"Train Loss: {running_loss / len(self.train_loader):.4f} - Evaluate Accuracy: {evaluate_accuracy:.4f}")
+        return running_loss / len(self.train_loader), evaluate_accuracy
 
     def train_model_epoch(self, model, dataloader, criterion, optimizer):
         running_loss = 0.0
@@ -122,7 +145,7 @@ class ImageModelTraining:
         with torch.no_grad():
             for data in data_loader:
                 images, labels = data
-                images, labels = labels.to(device).float(), labels.to(device)
+                images, labels = images.to(device).float(), labels.to(device)
 
                 outputs = model(images).to(device)
                 _, predicted = torch.max(outputs.data, 1)
@@ -139,6 +162,7 @@ class ImageModelTraining:
         with torch.no_grad():
             for data in data_loader:
                 images, labels = data
+                images, labels = images.to(device).float(), labels.to(device)
                 outputs = model(images).to(device)
                 for i in range(outputs.size(0)):  # iterate over batch size
                     output = outputs[i]
@@ -154,5 +178,6 @@ class ImageModelTraining:
         print("\nTraining Specifications: ", self.image_model.network_parameters)
         optimizer = optim.Adam(model.parameters(), **optimizer_params)  # get rid of lr
         train_loss, val_loss = self.train_model(model, criterion, optimizer)  # get rid of epochs
-        self.evaluate_predictions = self.get_eval_prediction(model, self.val_loader, num_classes=self.num_classes)
+        self.evaluate_predictions = self.get_eval_prediction(
+            model, self.val_loader, num_classes=self.num_classes, device=self.device)
         return model, train_loss, val_loss, self.evaluate_predictions
